<p align="center">
    <img width="500", src="https://raw.githubusercontent.com/tobin-wainer/elk/main/docs/_static/main-logo.png">
</p>

<h2 align="center">
    Welcome to the <b>E</b>nsemble <b>L</b>ight<b>K</b>urve (a.k.a. elk) Python package!
    <br>
    <a href='https://elk.readthedocs.io/en/latest/?badge=latest'>
        <img src='https://readthedocs.org/projects/elk/badge/?version=latest' alt='Documentation Status' />
    </a>
    <a href="mailto:tobinw@uw.edu?cc=tomwagg@uw.edu">
        <img src="https://img.shields.io/badge/contact-authors-blueviolet.svg?style=flat" alt="Email the authors"/>
    </a>
</h2>

<p align="center">
    This package allows you to download, correct, analyze and visualize <i>ensemble</i> light curves from TESS FFI data using the methods outlined in <a href="https://ui.adsabs.harvard.edu">Wainer+2023</a>. While originally designed for analysis of star clusters, it can be used to create ensemble light curves for any given aperture.
</p>

### Installation
Put simply? `pip install astro-elk`! But we recommend creating a conda environment first to ensure everything goes smoothly! Check out the installation instructions [here](https://elk.readthedocs.io/en/latest/pages/install.html) to learn exactly how to install `elk`

### Documentation
All documentation for `elk` can be found <a href="https://elk.readthedocs.io/en/latest/">here!</a>

### Logo design
We'd also like to acknowledge the absolutely splendid work of <a href="https://www.samanthalynnmartinez.com">Samantha-Lynn Martinez</a> in designing the `elk` logo. You can find more of her portfolio <a href="https://www.samanthalynnmartinez.com/illustrationdesign">here</a> and we encourage you to reach out to her for any design needs you have!
